<!--
  Include the contents of INSTALL.md from the project root without moving it, which may
  break links around the internet. Additionally, note that SUMMARY.md is unable to 
  directly link to content outside of the docs/ directory. So we use this file as a 
  redirection.
-->
{{#include ../../INSTALL.md}}